@@ -29,7 +29,7 @@ import lazygal.config
 from lazygal.generators import WebalbumDir
 from lazygal.sourcetree import Directory
 from lazygal.metadata import GEXIV2_DATE_FORMAT, GExiv2
-from lazygal.mediautils import VideoProcessor
+from lazygal.mediautils import VideoProcessor, HAVE_VIDEO
 
 
 class TestGenerators(LazygalTestGen):
@@ -476,6 +476,22 @@ class TestGenerators(LazygalTestGen):
         self.assertEqual(im.size, (400, 600, ))
         im.close()
 
+    def test_sizeasoriginal(self):
+        config = lazygal.config.LazygalConfig()
+        config.set('webgal', 'original', True)
+        config.set('webgal', 'image-size', 'std=0x0')
+        self.setup_album(config)
+
+        self.add_img(self.source_dir, 'img.jpg')
+
+        dest_dir = self.get_working_path()
+        self.album.generate(dest_dir)
+
+        shouldbeoriginal = os.path.join(dest_dir, 'img.jpg')
+        im = Image.open(shouldbeoriginal)
+        self.assertEqual(im.size, (640, 427, ))
+        im.close()
+
     def test_feed(self):
         config = lazygal.config.LazygalConfig()
         config.set('global', 'puburl', 'http://example.com/album/')
@@ -593,6 +609,7 @@ class TestGenerators(LazygalTestGen):
             print(os.listdir(dest_dir))
             raise
 
+    @unittest.skipIf(not HAVE_VIDEO, 'video support not available')
     def test_withvideo(self):
         source_subgal = self.setup_subgal('subgal', [], ['vid.mov',
                                                          'vid-silent.mov'])
@@ -629,6 +646,13 @@ class TestGenerators(LazygalTestGen):
             self.assertTrue(os.path.isfile(os.path.join(dest_subgal_path, fn)),
                             error % fn)
 
+    def test_brokenpics(self):
+        # create zero-size img in source_dir
+        self.create_file(os.path.join(self.source_dir, 'img.jpg'))
+
+        dest_dir = self.get_working_path()
+        self.album.generate(dest_dir)
+
 
 class TestSpecialGens(LazygalTestGen):
 
